'''
Copyright 2012 Dmytro Karpenko

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''
import numpy
import sys
import getopt
import string

# Import our own modules
import GridWorkloadFormats as GWFormats
import GeneratorGlobals as GGlobals

def usage():
	print "************************************"
	print "Usage: python generator.py <options>"
	print ""
	print "Mandatory options:"
	print "	-n<num>, -n <num>, --number_of_jobs <num>, --number_of_jobs=<num>"
	print "		number of jobs to generate"
	print ""
	print "Another options:"
	print "	-p, --poisson"
	print "		Generate interarrival times according to Poisson process"
	print ""
	print "	-s, --swf"
	print "		Output workload in SW format (only jobs, no files)"
	print ""
	print "	-e, --extendedswf"
	print "		Output workload in extended SW format (jobs and files)"
	print ""
	print "	-d, --dax"
	print "		Output workload in DAX format"
	print ""
	print "	-f<name>, -f <name>, --filename <name>, --filename=<name>"
	print "		The base filename of the output file"

	sys.exit(0)

# Get the options passed to the generator
try:
	options, remainder = getopt.getopt(sys.argv[1:], 'n:psedf:', \
								['number_of_jobs=', 'poisson', 'swf', 'extendedswf', 'dax', 'filename'])
except:
	usage()

n_present = False
format_present = False
swf_output = False
custom_swf_output = False
dax_output = False
gwa_output = False
base_output_filename = ''
poisson_interarrival = False

for opt, arg in options:
	if opt in ('-n', '--number_of_jobs'):
		n_present = True
		jobs_to_generate_str = arg
		if not(jobs_to_generate_str.isdigit()):
			print "Number of jobs should be positive integer number!"
			sys.exit(0)
	if opt in ('-p', '--poisson'):
		poisson_interarrival = True
	if opt in ('-s', '--swf'):
		if (not format_present):
			swf_output = True
			format_present = True
		else:
			print "Please, choose only one output format"
			sys.exit(0)
	if opt in ('-e', '--extendedswf'):
		if (not format_present):
			custom_swf_output = True
			format_present = True
		else:
			print "Please, choose only one output format"
			sys.exit(0)
	if opt in ('-d', '--dax'):
		if (not format_present):
			dax_output = True
			format_present = True
		else:
			print "Please, choose only one output format"
			sys.exit(0)
	if opt in ('-f', '--filename'):
		base_output_filename = arg
		valid_chars = "-_.() %s%s" % (string.ascii_letters, string.digits)
		for char in base_output_filename:
			if not(char in valid_chars):
				print "The provided base output filename may not be system-valid. Exiting."
				sys.exit(0)
			
if not n_present:
	usage()

if not format_present:
	# We will output values in default format then
	gwa_output = True
	
jobs_to_generate = int(jobs_to_generate_str)
if not(jobs_to_generate > 0):
	print "Number of jobs should be positive integer number!"
	sys.exit(0)

print "Generating %d jobs" % jobs_to_generate

# List of file in different categories of popularity still to distribute among jobs
active_100k = []
active_10k = []
active_1k = []
active_100 = []
active_60 = []
active_zipf = []

# Total number of files in different categories of popularity
files_number_100k = 0
files_number_10k = 0 
files_number_1k = 0
files_number_100 = 0
files_number_60 = 0
files_number_zipf = 0

# --------- Custom CDFs and their translations -----------

# *** CDF defining how many input files the job needs and its translation to a number of files ***
input_files_cdf = [ 0.000912, 0.022468, 0.042104, 0.661795, 0.785157, 0.852227, 0.874022, \
                    0.946992, 0.958112, 0.969300, 0.972629, 0.993981, 0.994064, 0.994420, \
                    0.994548, 0.994756, 0.995120, 0.997069, 0.997437, 0.997504, 0.997676, \
                    0.997727, 0.997956, 0.998094, 0.998282, 0.998459, 0.999054, 0.999131, \
                    0.999313, 0.999331, 0.999379, 0.999386, 0.999404, 0.999435, 0.999446, \
                    0.999489, 0.999510, 0.999520, 0.999526, 0.999546, 0.999573, 0.999585, \
                    0.999619, 0.999630, 0.999686, 0.999921, 0.999928, 0.999976, 1.000000 ]

input_files_number = [ 1, 2, 3, 4, 5, 8, 11, 12, 13, 24, 42, 43, 44, 45, 46, 51, 52, 53, \
                       54, 62, 63, 68, 69, 81, 83, 84, 85, 101, 103, 104, 105, 106,   \
                       107, 124, 125, 127, 133, 134, 136, 137, 152, 153, 170, 171,    \
                       202, 203, 204, 404, 405 ]


# *** CDFs defining from which category of popularity the job will request input files ***
# *** The jobs are divided by number of their input files ***
# *** From unique files to extremely popular files with >100k requests *** 
files_popularity_categories_cdf_1 = [ 0.975098296199 , 0.975753604194 , 0.976408912189 , 0.979685452163 , 0.983617300131 , 1.0  ]
files_popularity_categories_cdf_2 = [ 0.00131648235914 , 0.00135805548627 , 0.00146891715862 , 0.00163520966714 , 0.148152767384 , 1.0 ]
files_popularity_categories_cdf_3 = [ 0.320503458488 , 0.330828211526 , 0.331538165074 , 0.333282622366 , 0.416083490537 , 1.0  ]
files_popularity_categories_cdf_4 = [ 0.147120242181 , 0.24587221858 , 0.258306901007 , 0.26636675215 , 0.419211802476 , 1.0  ]
files_popularity_categories_cdf_5 = [ 0.254414428376 , 0.26760879883 , 0.35931461338 , 0.46101645664 , 0.686711674625 , 1.0  ]
files_popularity_categories_cdf_6_8 = [ 0.520020271787 , 0.530802203302 , 0.572926375527 , 0.621004130878 , 0.730100468283 , 1.0  ]
files_popularity_categories_cdf_9_11 = [ 0.580278275564 , 0.598278656612 , 0.697580344545 , 0.721067266035 , 0.81152201105 , 1.0  ]
files_popularity_categories_cdf_12 = [ 0.126850722276 , 0.128381107554 , 0.200618294756 , 0.752284320067 , 0.791860096995 , 1.0  ]
files_popularity_categories_cdf_13 = [ 0.70960329629 , 0.712983894631 , 0.717302629676 , 0.796271423199 , 0.84122346251 , 1.0  ]
files_popularity_categories_cdf_14_24 = [ 0.704771893026 , 0.718289674405 , 0.7641404872 , 0.841552652906 , 0.888750178767 , 1.0  ]
files_popularity_categories_cdf_25_42 = [ 0.530609247103 , 0.547091539023 , 0.883433625091 , 0.919872963773 , 0.94350737499 , 1.0  ]
files_popularity_categories_cdf_43 = [ 0.930315196314 , 0.930357491443 , 0.930454444893 , 0.930715373303 , 0.942822841972 , 1.0  ]
files_popularity_categories_cdf_44 = [ 0.833662714097 , 0.844861660079 , 0.934288537549 , 0.936429512516 , 0.948781291173 , 1.0  ]
files_popularity_categories_cdf_45 = [ 0.28319374651 , 0.360692350642 , 0.931099944165 , 0.931509398846 , 0.949674297413 , 1.0  ]
files_popularity_categories_cdf_46 = [ 0.902429067157 , 0.903959991835 , 0.903959991835 , 0.909165135742 , 0.919983670137 , 1.0  ]
files_popularity_categories_cdf_47_51 = [ 0.945521644895 , 0.946634643548 , 0.946986116806 , 0.950090797259 , 0.961630835921 , 1.0  ]
files_popularity_categories_cdf_52 = [ 0.962011349306 , 0.962515762926 , 0.962515762926 , 0.962547288777 , 0.968915510719 , 1.0  ]
files_popularity_categories_cdf_53 = [ 0.959297787081 , 0.962131156072 , 0.962131156072 , 0.962154285615 , 0.967138702086 , 1.0  ]
files_popularity_categories_cdf_54 = [ 0.944595001506 , 0.944715447154 , 0.944715447154 , 0.949924721469 , 0.972207166516 , 1.0  ]
files_popularity_categories_cdf_55_62 = [ 0.943653438352 , 0.945168130869 , 0.949106331415 , 0.954710693729 , 0.96258709482 , 1.0  ]
files_popularity_categories_cdf_63 = [ 0.931253802334 , 0.939881643714 , 0.965433327803 , 0.966539461313 , 0.967369061446 , 1.0  ]
files_popularity_categories_cdf_64_68 = [ 0.944571127872 , 0.944571127872 , 0.945097351342 , 0.945798982635 , 0.953516926855 , 1.0  ]
files_popularity_categories_cdf_69 = [ 0.965565520112 , 0.965792560639 , 0.970144170734 , 0.970182010822 , 0.970749612139 , 1.0  ]
files_popularity_categories_cdf_70_81 = [ 0.950086455331 , 0.950086455331 , 0.950144092219 , 0.95181556196 , 0.958386167147 , 1.0  ]
files_popularity_categories_cdf_82_83 = [ 0.727311182895 , 0.949084756191 , 0.955083833256 , 0.955776034456 , 0.96158283341 , 1.0  ]
files_popularity_categories_cdf_84 = [ 0.935145101812 , 0.935145101812 , 0.935145101812 , 0.935305435305 , 0.944765111432 , 1.0  ]
files_popularity_categories_cdf_85 = [ 0.929861070056 , 0.929884717706 , 0.929884717706 , 0.929908365356 , 0.942890925214 , 1.0  ]
files_popularity_categories_cdf_86_101 = [ 0.966614970207 , 0.966614970207 , 0.967431230104 , 0.969063749898 , 0.975430577096 , 1.0  ]
files_popularity_categories_cdf_102_103 = [ 0.978247617825 , 0.978247617825 , 0.978311784145 , 0.978536366261 , 0.979787609484 , 1.0  ]
files_popularity_categories_cdf_104 = [ 0.96858974359 , 0.96858974359 , 0.969230769231 , 0.970192307692 , 0.973076923077 , 1.0  ]
files_popularity_categories_cdf_105 = [ 0.959047619048 , 0.963095238095 , 0.963095238095 , 0.963095238095 , 0.964047619048 , 1.0  ]
files_popularity_categories_cdf_106 = [ 0.974056603774 , 0.974056603774 , 0.974056603774 , 0.975628930818 , 0.981918238994 , 1.0  ]
files_popularity_categories_cdf_107 = [ 0.955682845945 , 0.955682845945 , 0.955682845945 , 0.955682845945 , 0.976183298161 , 1.0  ]
files_popularity_categories_cdf_108_124 = [ 0.939131853786 , 0.939131853786 , 0.958224543081 , 0.958877284595 , 0.965894255875 , 1.0  ]
files_popularity_categories_cdf_125 = [ 0.938823529412 , 0.938823529412 , 0.938823529412 , 0.941647058824 , 0.942588235294 , 1.0  ]
files_popularity_categories_cdf_126_127 = [ 0.931439555745 , 0.931439555745 , 0.931439555745 , 0.932080307561 , 0.939982913285 , 1.0  ]
files_popularity_categories_cdf_128_133 = [ 0.981051206858 , 0.981051206858 , 0.981051206858 , 0.981051206858 , 0.985337243402 , 1.0  ]
files_popularity_categories_cdf_134 = [ 0.980684811238 , 0.980684811238 , 0.980684811238 , 0.982001755926 , 0.989025460931 , 1.0  ]
files_popularity_categories_cdf_135_136 = [ 0.884303610906 , 0.980103168755 , 0.980103168755 , 0.980103168755 , 0.98084008843 , 1.0  ]
files_popularity_categories_cdf_137 = [ 0.980092899801 , 0.980092899801 , 0.980092899801 , 0.980092899801 , 0.981198849812 , 1.0  ]
files_popularity_categories_cdf_138_152 = [ 0.981467181467 , 0.981467181467 , 0.981467181467 , 0.982084942085 , 0.985482625483 , 1.0  ]
files_popularity_categories_cdf_153 = [ 0.985371926548 , 0.985371926548 , 0.985371926548 , 0.985371926548 , 0.98661686897 , 1.0  ]
files_popularity_categories_cdf_154_170 = [ 0.984588856558 , 0.984588856558 , 0.984696626792 , 0.985235477961 , 0.989222976614 , 1.0  ]
files_popularity_categories_cdf_171 = [ 0.98343079922 , 0.98343079922 , 0.98343079922 , 0.98343079922 , 0.993827160494 , 1.0  ]
files_popularity_categories_cdf_172_202 = [ 0.986860815653 , 0.986860815653 , 0.986974574825 , 0.987315852341 , 0.989363517434 , 1.0  ]
files_popularity_categories_cdf_203 = [ 0.624940611638 , 0.99002275512 , 0.99002275512 , 0.990047760746 , 0.991985696782 , 1.0  ]
files_popularity_categories_cdf_204 = [ 0.984885620915 , 0.984885620915 , 0.984885620915 , 0.985294117647 , 0.993464052288 , 1.0  ]
files_popularity_categories_cdf_205_404 = [ 0.927843930203 , 0.988017673931 , 0.988017673931 , 0.988167453007 , 0.989028682693 , 1.0  ]
files_popularity_categories_cdf_405 = [ 0.936603269937 , 0.98985652319 , 0.98985652319 , 0.98985652319 , 0.990790790791 , 1.0  ]



# *** CDFs defining the number of output files per job ***
# *** The jobs are divided by number of their input files ***
upload_files_cdf_for_1 = [  0.0511140235911 ,  0.880078636959 ,  0.933158584535 ,  0.993446920052 ,  0.993446920052 ,\
			    0.993446920052 ,  0.993446920052 ,  0.996723460026 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_2 = [  0.0162966658352 ,  0.016878689615 ,  0.999833707491 ,  0.999889138328 ,  0.999889138328 ,\
			    0.999889138328 ,  0.999889138328 ,  0.999944569164 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_3 = [  0.0398283940851 ,  0.0398588206657 ,  0.966804600499 ,  0.981957037668 ,  0.982808981927 ,\
			    0.983204527475 ,  0.983204527475 ,  0.983204527475 ,  0.999634881032 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_4 = [  0.0140970539066 ,  0.014119228181 ,  0.976496233266 ,  0.990895050124 ,  0.996203378588 ,\
			    0.997574327204 ,  0.997574327204 ,  0.999002157653 ,  0.999119777717 ,  0.999119777717 ,\
			    0.999998071802 ,  0.999998071802 ,  1.0 ,  1.0 ]
upload_files_cdf_for_5 = [  0.0181864853346 ,  0.0183753729319 ,  0.79338602813 ,  0.883882560347 ,  0.927021581619 ,\
			    0.936010693944 ,  0.936010693944 ,  0.937144019528 ,  0.999191173622 ,  0.999743306598 ,\
			    0.999975783641 ,  0.999975783641 ,  0.999975783641 ,  1.0 ]
upload_files_cdf_for_6_8 = [  0.0333392729865 ,  0.0336154668567 ,  0.754668567356 ,  0.924162508909 ,  0.964691732003 ,\
			      0.994458303635 ,  0.994805773343 ,  0.996641126158 ,  0.997977548111 ,  0.997977548111 ,\
			      0.997986457591 ,  0.999643620813 ,  0.999688168211 ,  1.0 ]
upload_files_cdf_for_9_11 = [  0.0249574899896 ,  0.0258351160112 ,  0.906395699632 ,  0.9664856563 ,  0.990839778399 ,\
			       0.996242663595 ,  0.998299599583 ,  0.998299599583 ,  0.999012670726 ,  0.999122373978 ,\
			       0.999122373978 ,  0.999122373978 ,  1.0 ,  1.0 ]
upload_files_cdf_for_12 = [  0.0125514790768 ,  0.0125760416581 ,  0.619468301989 ,  0.997232615833 ,  0.999778936768 ,\
			     0.999959062364 ,  0.999959062364 ,  0.999959062364 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_13 = [  0.024606457852 ,  0.0250899908666 ,  0.757373878472 ,  0.938698758932 ,  0.998818030409 ,\
			     0.999301563423 ,  0.999301563423 ,  0.999301563423 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_14_24 = [  0.0619960484861 ,  0.0664281518663 ,  0.795856250334 ,  0.85080365248 ,  0.993752336199 ,\
			        0.994339723394 ,  0.995247503604 ,  0.995247503604 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_25_42 = [  0.0606713336923 ,  0.0610303356668 ,  0.901633458984 ,  0.955663256148 ,  0.996948483217 ,\
			        0.996948483217 ,  0.998922994076 ,  0.998922994076 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_43 = [  0.0059037493005 ,  0.00618354784555 ,  0.999804141018 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			     1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_44 = [  0.173913043478 ,  0.173913043478 ,  0.905797101449 ,  0.963768115942 ,  0.963768115942 ,  0.963768115942 ,\
			     1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_45 = [  0.725293132328 ,  0.725293132328 ,  0.978224455611 ,  0.998324958124 ,  0.998324958124 ,  0.998324958124 ,\
                             1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_46 = [  0.075117370892 ,  0.075117370892 ,  0.93896713615 ,  0.995305164319 ,  0.995305164319 ,  0.995305164319 ,\
                             1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_47_51 = [  0.155172413793 ,  0.158045977011 ,  0.824712643678 ,  0.997126436782 ,  0.997126436782 ,\
                                0.997126436782 ,  0.997126436782 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_52 = [  0.0983606557377 ,  0.0983606557377 ,  0.331147540984 ,  0.968852459016 ,  0.968852459016 ,\
			     0.968852459016 ,  0.97868852459 ,  0.97868852459 ,  0.97868852459 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_53 = [  0.00429053018694 ,  0.00429053018694 ,  0.396261109409 ,  0.9904995403 ,  0.999080600674 ,\
			     0.999080600674 ,  0.999387067116 ,  0.999387067116 ,  0.999693533558 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_54 = [  0.0390243902439 ,  0.0390243902439 ,  0.936585365854 ,  0.970731707317 ,  0.99837398374 ,\
			     0.99837398374 ,  0.99837398374 ,  0.99837398374 ,  0.99837398374 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_55_62 = [  0.0796460176991 ,  0.0796460176991 ,  0.973451327434 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
				1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_63 = [  0.324041811847 ,  0.324041811847 ,  0.996515679443 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			     1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_64_68 = [  0.0813953488372 ,  0.0813953488372 ,  0.96511627907 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
				1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_69 = [  0.00261096605744 ,  0.00261096605744 ,  0.997389033943 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			     1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_70_81 = [  0.282608695652 ,  0.282608695652 ,  0.965217391304 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
				1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_82_83 = [  0.215873015873 ,  0.215873015873 ,  0.987301587302 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
				1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_84 = [  0.286195286195 ,  0.286195286195 ,  0.993265993266 ,  0.993265993266 ,  0.993265993266 ,\
			     0.993265993266 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_85 = [  0.086432160804 ,  0.086432160804 ,  0.998994974874 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			     1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_86_101 = [  0.184615384615 ,  0.184615384615 ,  0.892307692308 ,  0.976923076923 ,  0.976923076923 ,\
				 0.976923076923 ,  0.992307692308 ,  0.992307692308 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_102_103 = [  0.0657894736842 ,  0.0657894736842 ,  0.980263157895 ,  0.990131578947 ,  0.990131578947 ,\
				  0.990131578947 ,  0.993421052632 ,  0.993421052632 ,  0.996710526316 ,  0.996710526316 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_104 = [  0.266666666667 ,  0.266666666667 ,  0.633333333333 ,  0.966666666667 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			      1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_105 = [  0.177215189873 ,  0.177215189873 ,  0.670886075949 ,  0.949367088608 ,  0.987341772152 ,\
			      0.987341772152 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_106 = [  0.333333333333 ,  0.333333333333 ,  0.916666666667 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			      1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_107 = [  0.0645161290323 ,  0.0645161290323 ,  0.903225806452 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			      1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_108_124 = [  0.384615384615 ,  0.384615384615 ,  0.942307692308 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
				  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_125 = [  0.235294117647 ,  0.235294117647 ,  0.882352941176 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			      1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_126_127 = [  0.297297297297 ,  0.297297297297 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
				  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_128_133 = [  0.0294117647059 ,  0.0294117647059 ,  0.941176470588 ,  0.941176470588 ,  0.941176470588 ,\
				  0.941176470588 ,  0.970588235294 ,  0.970588235294 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_134 = [  0.0 ,  0.0 ,  0.882352941176 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_135_136 = [  0.4 ,  0.4 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_137 = [  0.0 ,  0.0 ,  0.848484848485 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_138_152 = [  0.177777777778 ,  0.177777777778 ,  0.911111111111 ,  0.977777777778 ,  0.977777777778 ,\
				  0.977777777778 ,  0.977777777778 ,  0.977777777778 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_153 = [  0.047619047619 ,  0.047619047619 ,  0.714285714286 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
			      1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_154_170 = [  0.0701754385965 ,  0.0701754385965 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_171 = [  0.0 ,  0.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_172_202 = [  0.204301075269 ,  0.204301075269 ,  0.924731182796 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,\
				  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_203 = [  0.0381679389313 ,  0.0381679389313 ,  0.908396946565 ,  0.992366412214 ,  0.992366412214 ,\
			      0.992366412214 ,  0.992366412214 ,  0.994910941476 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_204 = [  0.0 ,  0.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_205_404 = [  0.2875 ,  0.2875 ,  0.9625 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]
upload_files_cdf_for_405 = [  0.162162162162 ,  0.162162162162 ,  0.972972972973 ,  0.972972972973 ,  0.972972972973 ,\
			      0.972972972973 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ,  1.0 ]


upload_sizes_cdf = [0.456175508381, 0.507905107373, 0.5656236954, 0.859155788703, 0.92845866635, 0.965559675558, 0.988823948793, 0.996420708852, \
		    0.999884439709, 1.0]
upload_sizes_cdf_translation = [ 1, 2, 10, 100, 300, 800, 1500, 2500, 4500, 5000 ]

walltimes_cdf = [ 0.012379059606, 0.0307033892706, 0.101147172254, 0.252337286947, 0.432722805193, 0.585706986495, 0.749870142307, 0.858356622864, \
		  0.918106314205, 0.950846211519, 0.969012348148, 0.998789005039, 1.0 ]
walltimes_cdf_translation = [ 1, 2, 10, 50, 250, 300, 400, 500, 600, 700, 800, 1500, 4000]


inter_arrival_cdf = [ 0.0395576764576 ,  0.271053668908 ,  0.726295137188 ,  0.818254356941 ,  0.860765435933 ,  0.883695067907 ,  0.899228949915 ,  0.910405294026 ,  0.918720212143 ,  0.925120943178 ,  0.930136650859 ,  0.93429888792 ,  0.937788023938 ,  0.940601669912 ,  0.942963197439 ,  0.944904260783 ,  0.946626730533 ,  0.94811448093 ,  0.94942544525 ,  0.950616959518 ,  0.951653785969 ,  0.962598994231 ,  0.969167552588 ,  0.973852980876 ,  0.977294934123 ,  0.979806371466 ,  0.981736087055 ,  0.983350454507 ,  0.984679933586 ,  0.985783652066 ,  0.986775684747 ,  0.987672157387 ,  0.988403788956 ,  0.989121086518 ,  0.989736851536 ,  0.990328726543 ,  0.990867446277 ,  0.991389443004 ,  0.991855298207 ,  0.99227695689 ,  0.992669350311 ,  0.993028894968 ,  0.99338007812 ,  0.993673327998 ,  0.993973147628 ,  0.994262814004 ,  0.994519034366 ,  0.994770476725 ,  0.995008182329 ,  0.995209455666 ,  0.995411326254 ,  0.995611405091 ,  0.995803719675 ,  0.995997228759 ,  0.996162667081 ,  0.996300631891 ,  0.996449944456 ,  0.996557449502 ,  0.996683469307 ,  0.996810086362 ,  0.996932522666 ,  0.99703405521 ,  0.997144546508 ,  0.997247273553 ,  0.997335069341 ,  0.997443171638 ,  0.997525592174 ,  0.997603831958 ,  0.997693419497 ,  0.998361742537 ,  0.998797137977 ,  0.999111291613 ,  0.999295244693 ,  0.999450529761 ,  0.999576549566 ,  0.999675095859 ,  0.999745571389 ,  0.999804699165 ,  0.999851881936 ,  0.999896078455 ,  0.99993012172 ,  0.999955803481 ,  0.999979096241 ,  1.0  ]

inter_arrival_cdf_translation = [0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20, 30, 40, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150, 160, 170, 180, 190, 200, 210, 220, 230, 240, 250, 260, 270, 280, 290, 300, 310, 320, 330, 340, 350, 360, 370, 380, 390, 400, 410, 420, 430, 440, 450, 460, 470, 480, 490, 500,600, 700, 800, 900, 1000, 1100, 1200, 1300, 1400, 1500, 1600, 1700, 1800, 1900, 2000]

global_file_id = 0
sizes_limits = [ 0, 20, 400, 500, 600, 4000, 6000, 100000 ]


def translate_cdf_to_number(custom_cdf, custom_cdf_translation, random_value):
	k = 0
	while(custom_cdf[k] < random_value):
                k += 1
        if k != 0:
                high_border = custom_cdf_translation[k] - custom_cdf_translation[k-1]
                return_value = numpy.random.random_integers(1,high_border) + custom_cdf_translation[k-1]
        else:
                return_value = 1
	return return_value


def translate_cdf_to_position(custom_cdf, random_value):
	k = 0
	while(custom_cdf[k] < random_value):
                k += 1
	return k


def gen_new_zipf_file():
	global global_file_id

	custom_cdf4 = [ 0.29438018247, 0.34405870761, 0.644703283618, 0.703142555522, 0.734177801441, \
	       	        0.766887064146, 0.824892541203, 0.836964199728, 0.840827696122, 0.849812234358, \
	               	0.867964091545, 0.886677371889, 0.904367504488, 0.919263248773, 0.932149112294, \
	                0.949587523678, 0.952839747628, 0.961537210547, 0.979510529513, 0.982476385227, \
	                0.986898122909, 0.990920359226, 0.992910795234, 0.993756465382, 0.999711156977, \
	                0.999899594347, 0.999926109924, 1]
	cdf_to_num_translation4 = [ 1, 10, 90, 170, 250, 300, 620, 730, 750, 850, 950, 1050, 1200, 1300, \
                  		    1400, 1600, 1700, 1900, 2800, 3100, 3400, 3700, 3940, 3960, 4700, \
			            5200, 5500, 8200]
	l = 0
	rsize = numpy.random.rand()
	while(custom_cdf4[l] < rsize):
		l += 1
	if l != 0:
		high_border = cdf_to_num_translation4[l] - cdf_to_num_translation4[l-1]
		file_size = numpy.random.random_integers(1,high_border) + cdf_to_num_translation4[l-1]
	else:
		file_size = 1
	file_pop = numpy.random.zipf(3)
	new_file = { "file_id" : global_file_id, "file_pop" : file_pop, "file_size" : file_size }
	global_file_id += 1
	active_zipf.append(new_file)
	GGlobals.global_files_list.append(new_file.copy())

def gen_new_60_file():
	global global_file_id

	custom_cdf3 = [ 0.721, 0.994, 1 ]
	cdf_to_num_translation3 = [ 100, 200, 750 ]
	l = 0
	rsize = numpy.random.rand()
	while(custom_cdf3[l] < rsize):
		l += 1
	if l != 0:
		high_border = cdf_to_num_translation3[l] - cdf_to_num_translation3[l-1]
		file_size = numpy.random.random_integers(1,high_border) + cdf_to_num_translation3[l-1]
	else:
		file_size = numpy.random.random_integers(1,100)

	cat_60_100_cdf = [   0.662428, 0.904808, 1 ]
	cat_60_100_cdf_to_num_translation = [ 84, 99, 100 ]
	l = 0
	rsize = numpy.random.rand()
	while(cat_60_100_cdf[l] < rsize):
		l += 1
	if l != 0:
		high_border = cat_60_100_cdf_to_num_translation[l] - cat_60_100_cdf_to_num_translation[l-1]
		file_pop = numpy.random.random_integers(1,high_border) + cat_60_100_cdf_to_num_translation[l-1]
	else:
		file_pop = numpy.random.random_integers(61,84)

	new_file = { "file_id" : global_file_id, "file_pop" : file_pop, "file_size" : file_size }
	global_file_id += 1
	active_60.append(new_file)
	GGlobals.global_files_list.append(new_file.copy())

def gen_new_100_file():
	global global_file_id

	custom_cdf2 = [ 0.427, 0.594, 0.769, 0.771, 0.994, 1]
	cdf_to_num_translation2 = [ 20, 170, 200, 250, 280, 510]

	l = 0
	rsize = numpy.random.rand()
	while(custom_cdf2[l] < rsize):
		l += 1
	if l != 0:
		high_border = cdf_to_num_translation2[l] - cdf_to_num_translation2[l-1]
		file_size = numpy.random.random_integers(1,high_border) + cdf_to_num_translation2[l-1]
	else:
		file_size = numpy.random.random_integers(1,20)

	cat_100_1k_cdf = [  0.330345, 0.819812, 0.873599, 0.891976, 0.996414, 0.996414, 1 ]
	cat_100_1k_cdf_to_num_translation = [ 119, 199, 285, 286, 874, 875, 1000 ]
	l = 0
	rsize = numpy.random.rand()
	while(cat_100_1k_cdf[l] < rsize):
		l += 1
	if l != 0:
		high_border = cat_100_1k_cdf_to_num_translation[l] - cat_100_1k_cdf_to_num_translation[l-1]
		file_pop = numpy.random.random_integers(1,high_border) + cat_100_1k_cdf_to_num_translation[l-1]
	else:
		file_pop = numpy.random.random_integers(101,1000)

	new_file = { "file_id" : global_file_id, "file_pop" : file_pop, "file_size" : file_size }
	global_file_id += 1
	active_100.append(new_file)
	GGlobals.global_files_list.append(new_file.copy())

def gen_new_1k_file():
	global global_file_id

	custom_cdf1 = [ 0.022, 0.036, 0.925, 0.937, 0.984, 1]
	cdf_to_num_translation1 = [ 20, 250, 280, 460, 500, 700]

	l = 0
	rsize = numpy.random.rand()
	while(custom_cdf1[l] < rsize):
		l += 1
	if l != 0:
		high_border = cdf_to_num_translation1[l] - cdf_to_num_translation1[l-1]
		file_size = numpy.random.random_integers(1,high_border) + cdf_to_num_translation1[l-1]
	else:
		file_size = numpy.random.random_integers(1,20)

	cat_1_10k_cdf = [ 0.034296, 0.953069,  1.0 ]
	cat_1_10k_cdf_to_num_translation = [ 1500, 2200, 10000 ]

	l = 0
	rsize = numpy.random.rand()
	while(cat_1_10k_cdf[l] < rsize):
		l += 1
	if l != 0:
		high_border = cat_1_10k_cdf_to_num_translation[l] - cat_1_10k_cdf_to_num_translation[l-1]
		file_pop = numpy.random.random_integers(1,high_border) + cat_1_10k_cdf_to_num_translation[l-1]
	else:
		file_pop = numpy.random.random_integers(1001,10000)

	new_file = { "file_id" : global_file_id, "file_pop" : file_pop, "file_size" : file_size }
	global_file_id += 1
	active_1k.append(new_file)
	GGlobals.global_files_list.append(new_file.copy())


def gen_new_10k_file():
	global global_file_id

	prob = numpy.random.rand()
	if (prob <= 0.3):
		file_size = 1
	else:
		file_size = numpy.random.randint(400,501)

	file_pop = numpy.random.random_integers(10001,100000)

	new_file = { "file_id" : global_file_id, "file_pop" : file_pop, "file_size" : file_size }
	global_file_id += 1
	active_10k.append(new_file)
	GGlobals.global_files_list.append(new_file.copy())


def gen_new_100k_file():
	global global_file_id
	
	prob = numpy.random.rand()
	if (prob <= 0.77):
		file_size = 1
	elif(prob <= 0.88):
		file_size = 480
	else:
		file_size = 490

	file_pop = numpy.random.random_integers(100001,1000000)

	new_file = { "file_id" : global_file_id, "file_pop" : file_pop, "file_size" : file_size }
	global_file_id += 1
	active_100k.append(new_file)
	GGlobals.global_files_list.append(new_file.copy())

def assign_files_to_job(files_specs,current_job_set):
	# Check if we have enough needed files at all
	num_zipf = files_specs.count(0)
	while(len(active_zipf) < num_zipf):
		gen_new_zipf_file()
	num_60 = files_specs.count(1)
	while(len(active_60) < num_60):
		gen_new_60_file()
	num_100 = files_specs.count(2)
	while(len(active_100) < num_100):
		gen_new_100_file()
	num_1k = files_specs.count(3)
	while(len(active_1k) < num_1k):
		gen_new_1k_file()
	num_10k = files_specs.count(4)
	while(len(active_10k) < num_10k):
		gen_new_10k_file()
	num_100k = files_specs.count(5)
	while(len(active_100k) < num_100k):
		gen_new_100k_file()

	for i in range(0,num_zipf):
		current_job_set.add(active_zipf[i]["file_id"])
	for i in range(0,num_60):
		current_job_set.add(active_60[i]["file_id"])
	for i in range(0,num_100):
		current_job_set.add(active_100[i]["file_id"])
	for i in range(0,num_1k):
		current_job_set.add(active_1k[i]["file_id"])
	for i in range(0,num_10k):
		current_job_set.add(active_10k[i]["file_id"])
	for i in range(0,num_100k):
		current_job_set.add(active_100k[i]["file_id"])

	for j in current_job_set:
		for i in range(len(active_zipf),0,-1):
			if j == active_zipf[i-1]["file_id"]:
				active_zipf[i-1]["file_pop"] -= 1
				if active_zipf[i-1]["file_pop"] == 0:
					del active_zipf[i-1]
		for i in range(len(active_60),0,-1):
			if j == active_60[i-1]["file_id"]:
				active_60[i-1]["file_pop"] -= 1
				if active_60[i-1]["file_pop"] == 0:
					del active_60[i-1]
		for i in range(len(active_100),0,-1):
			if j == active_100[i-1]["file_id"]:
				active_100[i-1]["file_pop"] -= 1
				if active_100[i-1]["file_pop"] == 0:
					del active_100[i-1]
		for i in range(len(active_1k),0,-1):
			if j == active_1k[i-1]["file_id"]:
				active_1k[i-1]["file_pop"] -= 1
				if active_1k[i-1]["file_pop"] == 0:
					del active_1k[i-1]
		for i in range(len(active_10k),0,-1):
			if j == active_10k[i-1]["file_id"]:
				active_10k[i-1]["file_pop"] -= 1
				if active_10k[i-1]["file_pop"] == 0:
					del active_10k[i-1]
		for i in range(len(active_100k),0,-1):
			if j == active_100k[i-1]["file_id"]:
				active_100k[i-1]["file_pop"] -= 1
				if active_100k[i-1]["file_pop"] == 0:
					del active_100k[i-1]
	
        				
def gen_output_file_size(num_of_files):
	for i in range(0,num_of_files):
		i = numpy.random.rand()
		k = 0
		while(upload_sizes_cdf[k] < i):
			k += 1
		if k == 0:
			GGlobals.size_of_out_files_values.append(1)
		else:
			GGlobals.size_of_out_files_values.append(numpy.random.random_integers(1,upload_sizes_cdf_translation[k] - upload_sizes_cdf_translation[k-1]) + upload_sizes_cdf_translation[k-1])
		
def gen_walltime_value():
	i = numpy.random.rand()
	k = 0
	while(walltimes_cdf[k] < i):
		k += 1
	if k == 0:
		GGlobals.walltimes_values.append(1)
	else:
		GGlobals.walltimes_values.append(numpy.random.random_integers(1,walltimes_cdf_translation[k] - walltimes_cdf_translation[k-1]) + walltimes_cdf_translation[k-1])
	

def gen_intertime_value():
	i = numpy.random.rand()
	k = 0
	if(poisson_interarrival):
  		GGlobals.intertimes_values.append(int(numpy.random.standard_exponential()))
	else:
  		while(inter_arrival_cdf[k] < i):
		  	k += 1
		if k == 0:
			GGlobals.intertimes_values.append(0)
		else:
			GGlobals.intertimes_values.append(numpy.random.random_integers(1,inter_arrival_cdf_translation[k] - inter_arrival_cdf_translation[k-1]) + inter_arrival_cdf_translation[k-1])


def gen_job(num_of_files,popularity_cdf,upload_cdf):
	job_file_set = set([])
        i = numpy.random.rand()
        file_positions = []
        for j in range(0,num_of_files):
        	i = numpy.random.rand()
                k = translate_cdf_to_position(popularity_cdf,i)
                file_positions.append(k)
        assign_files_to_job(file_positions,job_file_set)
        GGlobals.jobs_file_sets.append(job_file_set)
        i = numpy.random.rand()
        k = translate_cdf_to_position(upload_cdf,i)
	GGlobals.num_of_out_files_values.append(k)
        gen_output_file_size(k)
        gen_walltime_value()
	gen_intertime_value()


cdf_values = numpy.random.rand(jobs_to_generate)

# Main generation loop
for i in cdf_values:
	num_of_files = translate_cdf_to_number(input_files_cdf,input_files_number,i)
	if num_of_files == 1:
		job_file_set = set([])
		i = numpy.random.rand()
		file_positions = []
        	k = translate_cdf_to_position(files_popularity_categories_cdf_1,i)
		file_positions.append(k)
		i = numpy.random.rand()
		assign_files_to_job(file_positions,job_file_set)
		i = numpy.random.rand()
		k = translate_cdf_to_position(upload_files_cdf_for_1, i)
		GGlobals.num_of_out_files_values.append(k)
		GGlobals.jobs_file_sets.append(job_file_set)
		gen_output_file_size(k)
		gen_walltime_value()
		gen_intertime_value()
	elif(num_of_files == 2):
		gen_job(num_of_files,files_popularity_categories_cdf_2,upload_files_cdf_for_2)
	elif(num_of_files == 3):
		gen_job(num_of_files,files_popularity_categories_cdf_3,upload_files_cdf_for_3)
	elif(num_of_files == 4):
		gen_job(num_of_files,files_popularity_categories_cdf_4,upload_files_cdf_for_4)
	elif(num_of_files == 5):
		gen_job(num_of_files,files_popularity_categories_cdf_5,upload_files_cdf_for_5)
	elif(num_of_files >= 6) and (num_of_files <= 8):
		gen_job(num_of_files,files_popularity_categories_cdf_6_8,upload_files_cdf_for_6_8)
	elif(num_of_files >= 9) and (num_of_files <= 11):
		gen_job(num_of_files,files_popularity_categories_cdf_9_11,upload_files_cdf_for_9_11)
	elif(num_of_files == 12):
		gen_job(num_of_files,files_popularity_categories_cdf_12,upload_files_cdf_for_12)
	elif(num_of_files == 13):
		gen_job(num_of_files,files_popularity_categories_cdf_13,upload_files_cdf_for_13)
	elif(num_of_files >= 14) and (num_of_files <= 24):
		gen_job(num_of_files,files_popularity_categories_cdf_14_24,upload_files_cdf_for_14_24)
	elif(num_of_files >= 25) and (num_of_files <= 42):
		gen_job(num_of_files,files_popularity_categories_cdf_25_42,upload_files_cdf_for_25_42)
	elif(num_of_files == 43):
		gen_job(num_of_files,files_popularity_categories_cdf_43,upload_files_cdf_for_43)
	elif(num_of_files == 44):
		gen_job(num_of_files,files_popularity_categories_cdf_44,upload_files_cdf_for_44)
	elif(num_of_files == 45):
		gen_job(num_of_files,files_popularity_categories_cdf_45,upload_files_cdf_for_45)
	elif(num_of_files == 46):
		gen_job(num_of_files,files_popularity_categories_cdf_46,upload_files_cdf_for_46)
	elif(num_of_files >= 47) and (num_of_files <= 51):
		gen_job(num_of_files,files_popularity_categories_cdf_47_51,upload_files_cdf_for_47_51)
	elif(num_of_files == 52):
		gen_job(num_of_files,files_popularity_categories_cdf_52,upload_files_cdf_for_52)
	elif(num_of_files == 53):
		gen_job(num_of_files,files_popularity_categories_cdf_53,upload_files_cdf_for_53)
	elif(num_of_files == 54):
		gen_job(num_of_files,files_popularity_categories_cdf_54,upload_files_cdf_for_54)
	elif(num_of_files >= 55) and (num_of_files <= 62):
		gen_job(num_of_files,files_popularity_categories_cdf_55_62,upload_files_cdf_for_55_62)
	elif(num_of_files == 63):
		gen_job(num_of_files,files_popularity_categories_cdf_63,upload_files_cdf_for_63)
	elif(num_of_files >= 64) and (num_of_files <= 68):
		gen_job(num_of_files,files_popularity_categories_cdf_64_68,upload_files_cdf_for_64_68)
	elif(num_of_files == 69):
		gen_job(num_of_files,files_popularity_categories_cdf_69,upload_files_cdf_for_69)
	elif(num_of_files >= 70) and (num_of_files <= 81):
		gen_job(num_of_files,files_popularity_categories_cdf_70_81,upload_files_cdf_for_70_81)
	elif(num_of_files >= 82) and (num_of_files <= 83):
		gen_job(num_of_files,files_popularity_categories_cdf_82_83,upload_files_cdf_for_82_83)
	elif(num_of_files == 84):
		gen_job(num_of_files,files_popularity_categories_cdf_84,upload_files_cdf_for_84)
	elif(num_of_files == 85):
		gen_job(num_of_files,files_popularity_categories_cdf_85,upload_files_cdf_for_85)
	elif(num_of_files >= 86) and (num_of_files <= 101):
		gen_job(num_of_files,files_popularity_categories_cdf_86_101,upload_files_cdf_for_86_101)
	elif(num_of_files >= 102) and (num_of_files <= 103):
		gen_job(num_of_files,files_popularity_categories_cdf_102_103,upload_files_cdf_for_102_103)
	elif(num_of_files == 104):
		gen_job(num_of_files,files_popularity_categories_cdf_104,upload_files_cdf_for_104)
	elif(num_of_files == 105):
		gen_job(num_of_files,files_popularity_categories_cdf_105,upload_files_cdf_for_105)
	elif(num_of_files == 106):
		gen_job(num_of_files,files_popularity_categories_cdf_106,upload_files_cdf_for_106)
	elif(num_of_files == 107):
		gen_job(num_of_files,files_popularity_categories_cdf_107,upload_files_cdf_for_107)
	elif(num_of_files >= 108) and (num_of_files <= 124):
		gen_job(num_of_files,files_popularity_categories_cdf_108_124,upload_files_cdf_for_108_124)
	elif(num_of_files == 125):
		gen_job(num_of_files,files_popularity_categories_cdf_125,upload_files_cdf_for_125)
	elif(num_of_files >= 126) and (num_of_files <= 127):
		gen_job(num_of_files,files_popularity_categories_cdf_126_127,upload_files_cdf_for_126_127)
	elif(num_of_files >= 128) and (num_of_files <= 133):
		gen_job(num_of_files,files_popularity_categories_cdf_128_133,upload_files_cdf_for_128_133)
	elif(num_of_files == 134):
		gen_job(num_of_files,files_popularity_categories_cdf_134,upload_files_cdf_for_134)
	elif(num_of_files >= 135) and (num_of_files <= 136):
		gen_job(num_of_files,files_popularity_categories_cdf_135_136,upload_files_cdf_for_135_136)
	elif(num_of_files == 137):
		gen_job(num_of_files,files_popularity_categories_cdf_137,upload_files_cdf_for_137)
	elif(num_of_files >= 138) and (num_of_files <= 152):
		gen_job(num_of_files,files_popularity_categories_cdf_138_152,upload_files_cdf_for_138_152)
	elif(num_of_files == 153):
		gen_job(num_of_files,files_popularity_categories_cdf_153,upload_files_cdf_for_153)
	elif(num_of_files >= 154) and (num_of_files <= 170):
		gen_job(num_of_files,files_popularity_categories_cdf_154_170,upload_files_cdf_for_154_170)
	elif(num_of_files == 171):
		gen_job(num_of_files,files_popularity_categories_cdf_171,upload_files_cdf_for_171)
	elif(num_of_files >= 172) and (num_of_files <= 202):
		gen_job(num_of_files,files_popularity_categories_cdf_172_202,upload_files_cdf_for_172_202)
	elif(num_of_files == 203):
		gen_job(num_of_files,files_popularity_categories_cdf_203,upload_files_cdf_for_203)
	elif(num_of_files == 204):
		gen_job(num_of_files,files_popularity_categories_cdf_204,upload_files_cdf_for_204)
	elif(num_of_files >= 205) and (num_of_files <= 404):
		gen_job(num_of_files,files_popularity_categories_cdf_205_404,upload_files_cdf_for_205_404)
	elif(num_of_files == 405):
		gen_job(num_of_files,files_popularity_categories_cdf_405,upload_files_cdf_for_405)

# Get rid of excessive popularity
# (we may have generated higher popularity than 
# needed to satisfy all our job requests)
for i in active_100k:
	GGlobals.global_files_list[i["file_id"]]["file_pop"] -= i["file_pop"]
for i in active_10k:
	GGlobals.global_files_list[i["file_id"]]["file_pop"] -= i["file_pop"]
for i in active_1k:
	GGlobals.global_files_list[i["file_id"]]["file_pop"] -= i["file_pop"]
for i in active_100:
	GGlobals.global_files_list[i["file_id"]]["file_pop"] -= i["file_pop"]
for i in active_60:
	GGlobals.global_files_list[i["file_id"]]["file_pop"] -= i["file_pop"]
for i in active_zipf:
	GGlobals.global_files_list[i["file_id"]]["file_pop"] -= i["file_pop"]

# The first job to arrive always has interarrival time at 0 seconds
GGlobals.intertimes_values[0] = 0

print "Creating output files..."

if gwa_output:
	GWFormats.gen_gwa_output(base_output_filename)
elif swf_output:
	GWFormats.gen_swf_output(base_output_filename)
elif custom_swf_output:
	GWFormats.gen_swf_output(base_output_filename,extended = True)
elif dax_output:
	GWFormats.gen_dax_output(base_output_filename)

print "Done"
sys.exit(0)
